@@ -6,10 +6,21 @@ import (
 	"io"
 	"os"
 	"os/signal"
+	"sort"
 	"strings"
 	"syscall"
 
-	"github.com/bmf-san/ggc/v5/git"
+	commandregistry "github.com/bmf-san/ggc/v7/cmd/command"
+	"github.com/bmf-san/ggc/v7/git"
+)
+
+// Interactive mode special return values
+// These constants are used to signal special states when returning from interactive mode
+const (
+	// InteractiveQuitCommand signals that the user wants to quit the interactive mode
+	InteractiveQuitCommand = "quit"
+	// InteractiveWorkflowCommand signals that a workflow has been executed and the interactive mode should restart
+	InteractiveWorkflowCommand = "workflow-executed"
 )
 
 // Executer is an interface for executing commands.
@@ -34,6 +45,7 @@ type Executer interface {
 	Clean(args []string)
 	Restore(args []string)
 	Add(args []string)
+	DebugKeys(args []string)
 	Interactive()
 }
 
@@ -61,6 +73,8 @@ type Cmd struct {
 	differ       *Differ
 	restorer     *Restorer
 	fetcher      *Fetcher
+	cmdRouter    *commandRouter
+	debugger     *Debugger
 }
 
 // GitDeps is a composite for wiring commands that depend on git operations.
@@ -90,7 +104,7 @@ type GitDeps interface {
 
 // NewCmd creates a new Cmd with the provided git client.
 func NewCmd(client GitDeps) *Cmd {
-	return &Cmd{
+	cmd := &Cmd{
 		gitClient:    client,
 		outputWriter: os.Stdout,
 		helper:       NewHelper(),
@@ -113,7 +127,10 @@ func NewCmd(client GitDeps) *Cmd {
 		differ:       NewDiffer(client),
 		restorer:     NewRestorer(client),
 		fetcher:      NewFetcher(client),
+		debugger:     NewDebugger(),
 	}
+	cmd.cmdRouter = mustNewCommandRouter(cmd)
+	return cmd
 }
 
 // SetDefaultRemote sets the default remote used by tag operations.
@@ -224,6 +241,11 @@ func (c *Cmd) Clean(args []string) {
 	c.cleaner.Clean(args)
 }
 
+// DebugKeys executes the debug-keys command with the given arguments.
+func (c *Cmd) DebugKeys(args []string) {
+	c.debugger.DebugKeys(args)
+}
+
 // Interactive starts the interactive UI mode.
 func (c *Cmd) Interactive() {
 	// Reset existing signal handlers
@@ -238,17 +260,27 @@ func (c *Cmd) Interactive() {
 		os.Exit(0)
 	}()
 
+	// Create persistent UI instance to preserve state
+	ui := NewUI(c.gitClient, c)
+
 	for {
-		args := InteractiveUI(c.gitClient)
+		args := ui.Run()
 		if args == nil {
 			break
 		}
 
 		// Check for "quit" command
-		if len(args) >= 2 && args[1] == "quit" {
+		if len(args) >= 2 && args[1] == InteractiveQuitCommand {
 			break
 		}
 
+		// Check for workflow execution
+		if len(args) >= 2 && args[1] == InteractiveWorkflowCommand {
+			// Workflow was executed, wait for user to continue
+			c.waitForContinue()
+			continue
+		}
+
 		c.Route(args[1:]) // Skip "ggc" in args
 
 		// Wait for user to continue
@@ -275,59 +307,104 @@ func (c *Cmd) Route(args []string) {
 
 // routeCommand routes to the appropriate command handler
 func (c *Cmd) routeCommand(cmd string, args []string) {
-	// Handle core commands first
-	if c.handleCoreCommand(cmd, args) {
+
+	if c.cmdRouter.route(cmd, args) {
 		return
 	}
 
-	// Handle extended commands
-	c.routeExtendedCommand(cmd, args)
-}
-
-// handleCoreCommand handles core git commands
-func (c *Cmd) handleCoreCommand(cmd string, args []string) bool {
-	coreCommands := map[string]func([]string){
-		"help":    func([]string) { c.Help() },
-		"add":     c.adder.Add,
-		"branch":  c.Branch,
-		"commit":  c.Commit,
-		"log":     c.Log,
-		"pull":    c.Pull,
-		"push":    c.Push,
-		"reset":   c.Reset,
-		"clean":   c.Clean,
-		"version": c.Version,
-	}
-
-	if handler, exists := coreCommands[cmd]; exists {
-		handler(args)
-		return true
-	}
-	return false
-}
-
-// routeExtendedCommand routes to extended command handlers
-func (c *Cmd) routeExtendedCommand(cmd string, args []string) {
-	extendedCommands := map[string]func([]string){
-		"remote":  c.remoter.Remote,
-		"rebase":  c.rebaser.Rebase,
-		"stash":   c.stasher.Stash,
-		"config":  c.configurer.Config,
-		"hook":    c.hooker.Hook,
-		"tag":     c.tagger.Tag,
-		"status":  c.statuser.Status,
-		"fetch":   c.fetcher.Fetch,
-		"diff":    c.differ.Diff,
-		"restore": c.restorer.Restore,
-	}
-
-	if handler, exists := extendedCommands[cmd]; exists {
-		handler(args)
-		return
-	}
 	c.Help()
 }
 
+type commandRouter struct {
+	handlers map[string]func([]string)
+}
+
+func mustNewCommandRouter(cmd *Cmd) *commandRouter {
+	router, err := newCommandRouter(cmd)
+	if err != nil {
+		panic(err)
+	}
+	return router
+}
+
+func newCommandRouter(cmd *Cmd) (*commandRouter, error) {
+	if err := commandregistry.ValidateAll(); err != nil {
+		return nil, fmt.Errorf("command registry validation failed: %w", err)
+	}
+
+	handlers := map[string]func([]string){
+		"help":    func([]string) { cmd.Help() },
+		"add":     func(args []string) { cmd.Add(args) },
+		"branch":  func(args []string) { cmd.Branch(args) },
+		"commit":  func(args []string) { cmd.Commit(args) },
+		"log":     func(args []string) { cmd.Log(args) },
+		"pull":    func(args []string) { cmd.Pull(args) },
+		"push":    func(args []string) { cmd.Push(args) },
+		"reset":   func(args []string) { cmd.Reset(args) },
+		"clean":   func(args []string) { cmd.Clean(args) },
+		"version": func(args []string) { cmd.Version(args) },
+		"remote":  func(args []string) { cmd.Remote(args) },
+		"rebase":  func(args []string) { cmd.Rebase(args) },
+		"stash":   func(args []string) { cmd.Stash(args) },
+		"config":  func(args []string) { cmd.Config(args) },
+		"hook":    func(args []string) { cmd.Hook(args) },
+		"tag":     func(args []string) { cmd.Tag(args) },
+		"status":  func(args []string) { cmd.Status(args) },
+		"fetch":   func(args []string) { cmd.Fetch(args) },
+		"diff":    func(args []string) { cmd.Diff(args) },
+		"restore": func(args []string) { cmd.Restore(args) },
+		InteractiveQuitCommand: func([]string) {
+			_, _ = fmt.Fprintln(cmd.outputWriter, "The 'quit' command is only available in interactive mode.")
+		},
+	}
+
+	available := make(map[string]struct{}, len(handlers))
+	for key := range handlers {
+		available[key] = struct{}{}
+	}
+
+	missing := missingHandlers(available)
+	if len(missing) > 0 {
+		sort.Strings(missing)
+		return nil, fmt.Errorf("no handler registered for commands: %s", strings.Join(missing, ", "))
+	}
+
+	return &commandRouter{handlers: handlers}, nil
+}
+
+func (r *commandRouter) route(cmd string, args []string) bool {
+	info, ok := commandregistry.Find(cmd)
+	if !ok {
+		return false
+	}
+	identifier := strings.TrimSpace(info.HandlerID)
+	if identifier == "" {
+		return false
+	}
+	handler, ok := r.handlers[identifier]
+	if !ok {
+		return false
+	}
+	handler(args)
+	return true
+}
+
+func missingHandlers(available map[string]struct{}) []string {
+	var missing []string
+	allCommands := commandregistry.All()
+	for i := range allCommands {
+		info := &allCommands[i]
+		id := strings.TrimSpace(info.HandlerID)
+		if id == "" || info.Hidden {
+			continue
+		}
+		if _, ok := available[id]; !ok {
+			missing = append(missing, id)
+		}
+	}
+	return missing
+}
+
 // isLegacyLike reports whether args resemble the pre-v6, flag-driven CLI surface
 // instead of the unified subcommand style introduced in v6.
 // Definition of "legacy-like":
