@@ -1,13 +1,13 @@
 package cmd
 
 import (
-	"bufio"
 	"bytes"
 	"io"
 	"strings"
 	"testing"
 
-	"github.com/bmf-san/ggc/v5/git"
+	"github.com/bmf-san/ggc/v7/git"
+	"github.com/bmf-san/ggc/v7/internal/prompt"
 )
 
 // mockGitClient is a mock of git.Client.
@@ -120,6 +120,9 @@ func (m *mockGitClient) CommitAmendWithMessage(_ string) error { return nil }
 func (m *mockGitClient) Diff() (string, error)       { return "", nil }
 func (m *mockGitClient) DiffStaged() (string, error) { return "", nil }
 func (m *mockGitClient) DiffHead() (string, error)   { return "", nil }
+func (m *mockGitClient) DiffWith(_ []string) (string, error) {
+	return "", nil
+}
 
 // Branch Operations methods
 func (m *mockGitClient) CheckoutNewBranch(_ string) error { return nil }
@@ -471,7 +474,7 @@ func TestCmd_Branch(t *testing.T) {
 		outputWriter: &buf,
 		helper:       helper,
 		// help path does not access gitClient; pass nil to minimize dependencies
-		brancher: &Brancher{gitClient: nil, inputReader: bufio.NewReader(strings.NewReader("")), outputWriter: &buf, helper: helper},
+		brancher: &Brancher{gitClient: nil, prompter: prompt.New(strings.NewReader(""), &buf), outputWriter: &buf, helper: helper},
 	}
 
 	cmd.Branch([]string{})
@@ -494,7 +497,7 @@ func TestCmd_Route(t *testing.T) {
 		helper:       helper,
 		// Initialize all components with mock clients to avoid side effects
 		adder:      &Adder{gitClient: mockClient, outputWriter: io.Discard},
-		brancher:   &Brancher{gitClient: mockClient, inputReader: bufio.NewReader(strings.NewReader("")), outputWriter: io.Discard, helper: helper},
+		brancher:   &Brancher{gitClient: mockClient, prompter: prompt.New(strings.NewReader(""), io.Discard), outputWriter: io.Discard, helper: helper},
 		committer:  &Committer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		logger:     &Logger{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		puller:     &Puller{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
@@ -502,7 +505,7 @@ func TestCmd_Route(t *testing.T) {
 		resetter:   &Resetter{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		cleaner:    &Cleaner{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		remoter:    &Remoter{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		rebaser:    &Rebaser{gitClient: mockClient, outputWriter: io.Discard, helper: helper, inputReader: bufio.NewReader(strings.NewReader(""))},
+		rebaser:    &Rebaser{gitClient: mockClient, outputWriter: io.Discard, helper: helper, prompter: prompt.New(strings.NewReader(""), io.Discard)},
 		stasher:    &Stasher{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		configurer: &Configurer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		hooker:     &Hooker{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
@@ -513,6 +516,7 @@ func TestCmd_Route(t *testing.T) {
 		restorer:   &Restorer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		fetcher:    &Fetcher{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 	}
+	cmd.cmdRouter = mustNewCommandRouter(cmd)
 
 	testCases := []struct {
 		name string
@@ -568,7 +572,7 @@ func TestCmd_Route_SeparatorAllowsHyphenValues(t *testing.T) {
 		outputWriter: &buf, // capture legacy-like error output if any
 		helper:       helper,
 		adder:        &Adder{gitClient: mockClient, outputWriter: io.Discard},
-		brancher:     &Brancher{gitClient: mockClient, inputReader: bufio.NewReader(strings.NewReader("")), outputWriter: io.Discard, helper: helper},
+		brancher:     &Brancher{gitClient: mockClient, prompter: prompt.New(strings.NewReader(""), io.Discard), outputWriter: io.Discard, helper: helper},
 		committer:    &Committer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		logger:       &Logger{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		puller:       &Puller{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
@@ -576,7 +580,7 @@ func TestCmd_Route_SeparatorAllowsHyphenValues(t *testing.T) {
 		resetter:     &Resetter{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		cleaner:      &Cleaner{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		remoter:      &Remoter{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
-		rebaser:      &Rebaser{gitClient: mockClient, outputWriter: io.Discard, helper: helper, inputReader: bufio.NewReader(strings.NewReader(""))},
+		rebaser:      &Rebaser{gitClient: mockClient, outputWriter: io.Discard, helper: helper, prompter: prompt.New(strings.NewReader(""), io.Discard)},
 		stasher:      &Stasher{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		configurer:   &Configurer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		hooker:       &Hooker{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
@@ -587,6 +591,7 @@ func TestCmd_Route_SeparatorAllowsHyphenValues(t *testing.T) {
 		restorer:     &Restorer{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 		fetcher:      &Fetcher{gitClient: mockClient, outputWriter: io.Discard, helper: helper},
 	}
+	cmd.cmdRouter = mustNewCommandRouter(cmd)
 
 	// Using "--" should allow a value starting with '-' to pass through
 	// without triggering the legacy-like error.
@@ -810,3 +815,36 @@ func TestCmd_waitForContinue(t *testing.T) {
 	// but we can verify the function is callable
 	_ = cmd.waitForContinue
 }
+
+// TestCmd_InteractiveWorkflowIntegration tests workflow integration with Cmd
+func TestCmd_InteractiveWorkflowIntegration(t *testing.T) {
+	// Setup
+	mockClient := &mockGitClient{}
+	cmd := NewCmd(mockClient)
+
+	// Test that NewUI creates workflow-enabled UI
+	ui := NewUI(mockClient, cmd)
+
+	if ui.workflow == nil {
+		t.Error("Expected UI to have workflow initialized")
+	}
+
+	if ui.workflowEx == nil {
+		t.Error("Expected UI to have workflow executor initialized")
+	}
+
+	// Test workflow operations
+	id := ui.AddToWorkflow("add", []string{"."}, "add .")
+	if id != 1 {
+		t.Errorf("Expected workflow ID 1, got %d", id)
+	}
+
+	if ui.workflow.IsEmpty() {
+		t.Error("Expected workflow to have steps after adding")
+	}
+
+	ui.ClearWorkflow()
+	if !ui.workflow.IsEmpty() {
+		t.Error("Expected workflow to be empty after clearing")
+	}
+}
