@@ -1,15 +1,18 @@
 package cmd
 
 import (
+	"bufio"
 	"bytes"
 	"fmt"
-	"reflect"
+	"os"
+	"slices"
 	"strings"
 	"testing"
 
 	"golang.org/x/term"
 
-	"github.com/bmf-san/ggc/v5/internal/testutil"
+	"github.com/bmf-san/ggc/v7/internal/termio"
+	"github.com/bmf-san/ggc/v7/internal/testutil"
 )
 
 // mockTerminal mocks terminal operations
@@ -20,7 +23,7 @@ type mockTerminal struct {
 	shouldFailRest bool
 }
 
-func (m *mockTerminal) makeRaw(_ int) (*term.State, error) {
+func (m *mockTerminal) MakeRaw(_ int) (*term.State, error) {
 	m.makeRawCalled = true
 	if m.shouldFailRaw {
 		return nil, fmt.Errorf("mock makeRaw error")
@@ -28,7 +31,7 @@ func (m *mockTerminal) makeRaw(_ int) (*term.State, error) {
 	return &term.State{}, nil
 }
 
-func (m *mockTerminal) restore(_ int, _ *term.State) error {
+func (m *mockTerminal) Restore(_ int, _ *term.State) error {
 	m.restoreCalled = true
 	if m.shouldFailRest {
 		return fmt.Errorf("mock restore error")
@@ -104,6 +107,7 @@ func TestUI_Run(t *testing.T) {
 					colors:    colors,
 					gitClient: mockGitClient,
 					gitStatus: getGitStatus(mockGitClient),
+					workflow:  NewWorkflow(),
 				},
 				inputBytes: tt.input,
 			}
@@ -183,7 +187,7 @@ func TestExtractPlaceholders(t *testing.T) {
 			if len(tt.want) == 0 && len(got) == 0 {
 				return
 			}
-			if !reflect.DeepEqual(got, tt.want) {
+			if !slices.Equal(got, tt.want) {
 				t.Errorf("extractPlaceholders() = %v, want %v", got, tt.want)
 			}
 		})
@@ -640,11 +644,12 @@ func TestUIState_GetSelectedCommand(t *testing.T) {
 	}
 
 	cmd := state.GetSelectedCommand()
-	if cmd == nil {
-		t.Fatal("Expected non-nil command")
-	}
-	if cmd.Command != "cmd2" {
-		t.Errorf("Expected 'cmd2', got '%s'", cmd.Command)
+	if cmd == nil || cmd.Command != "cmd2" {
+		if cmd == nil {
+			t.Fatal("Expected non-nil command")
+		} else {
+			t.Errorf("Expected 'cmd2', got '%s'", cmd.Command)
+		}
 	}
 
 	// Test out of bounds
@@ -700,8 +705,8 @@ func TestRenderer_KeybindHelp(t *testing.T) {
 
 	state := &UIState{
 		selected:  0,
-		input:     "nonexistent",
-		cursorPos: 11,
+		input:     "", // Empty input to show keybind help
+		cursorPos: 0,
 		filtered:  []CommandInfo{}, // Empty to trigger keybind help
 	}
 
@@ -717,6 +722,7 @@ func TestRenderer_KeybindHelp(t *testing.T) {
 		colors:    colors,
 		gitClient: mockGitClient,
 		gitStatus: getGitStatus(mockGitClient),
+		workflow:  NewWorkflow(),
 	}
 
 	renderer.Render(ui, state)
@@ -730,7 +736,10 @@ func TestRenderer_KeybindHelp(t *testing.T) {
 		"Ctrl+k",
 		"Ctrl+a",
 		"Ctrl+e",
-		"Backspace",
+		"Enter",
+		"Ctrl+c",
+		"Tab",
+		"Ctrl+t",
 	}
 
 	for _, keybind := range expectedKeybinds {
@@ -766,6 +775,7 @@ func TestRenderer_EmptyState(t *testing.T) {
 		renderer: renderer,
 		state:    state,
 		colors:   colors,
+		workflow: NewWorkflow(),
 	}
 
 	renderer.Render(ui, state)
@@ -800,13 +810,12 @@ func TestGetGitStatus(t *testing.T) {
 
 	status := getGitStatus(mockClient)
 
-	if status == nil {
-		t.Fatal("Expected status to be non-nil with mock client")
-	}
-
-	// Branch name should match mock
-	if status.Branch != "main" {
-		t.Errorf("Expected branch name to be 'main', got %s", status.Branch)
+	if status == nil || status.Branch != "main" {
+		if status == nil {
+			t.Fatal("Expected status to be non-nil with mock client")
+		} else {
+			t.Errorf("Expected branch name to be 'main', got %s", status.Branch)
+		}
 	}
 
 	// Should have 1 modified and 1 staged file
@@ -859,6 +868,7 @@ func TestRenderer_RenderGitStatus(t *testing.T) {
 		term:      &mockTerminal{},
 		renderer:  renderer,
 		colors:    colors,
+		workflow:  NewWorkflow(),
 		gitStatus: mockStatus,
 	}
 
@@ -901,6 +911,7 @@ func TestRenderer_RenderHeader(t *testing.T) {
 		term:      &mockTerminal{},
 		renderer:  renderer,
 		colors:    colors,
+		workflow:  NewWorkflow(),
 		gitStatus: nil, // No git status
 	}
 
@@ -910,11 +921,6 @@ func TestRenderer_RenderHeader(t *testing.T) {
 	// Check that header elements are present
 	expectedElements := []string{
 		"🚀 ggc Interactive Mode",
-		"Type to search",
-		"Ctrl+n/p",
-		"navigate",
-		"Enter",
-		"execute",
 	}
 
 	for _, element := range expectedElements {
@@ -989,6 +995,7 @@ func TestRenderer_RenderCommandItem(t *testing.T) {
 		term:     &mockTerminal{},
 		renderer: renderer,
 		colors:   colors,
+		workflow: NewWorkflow(),
 	}
 
 	cmd := CommandInfo{
@@ -1027,14 +1034,19 @@ func TestKeyHandler_InteractiveInput(t *testing.T) {
 		stdout:    &stdout,
 		stderr:    &stderr,
 		colors:    colors,
+		workflow:  NewWorkflow(),
 		term:      mockTerm,
 		gitClient: mockGitClient,
 	}
 
 	handler := &KeyHandler{ui: ui}
+	ui.handler = handler
 
 	placeholders := []string{"message"}
-	result := handler.interactiveInput(placeholders)
+	result, canceled := handler.interactiveInput(placeholders)
+	if canceled {
+		t.Fatal("interactive input should not be canceled")
+	}
 
 	if len(result) != 1 {
 		t.Errorf("Expected 1 input, got %d", len(result))
@@ -1097,9 +1109,13 @@ func TestKeyHandler_ProcessCommand_NoPlaceholders(t *testing.T) {
 	}
 
 	handler := &KeyHandler{ui: ui}
+	ui.handler = handler
 
 	// Command without placeholders should execute immediately
-	result := handler.processCommand("status")
+	result, canceled := handler.processCommand("status")
+	if canceled {
+		t.Fatal("processCommand should not cancel for commands without placeholders")
+	}
 
 	expected := []string{"ggc", "status"}
 	if len(result) != len(expected) {
@@ -1121,16 +1137,21 @@ func TestKeyHandler_ProcessCommand_WithPlaceholders(t *testing.T) {
 	mockTerm := &mockTerminal{shouldFailRaw: true}
 
 	ui := &UI{
-		stdin:  strings.NewReader("fix bug\n"),
-		stdout: &stdout,
-		stderr: &stderr,
-		colors: colors,
-		term:   mockTerm,
+		stdin:    strings.NewReader("fix bug\n"),
+		stdout:   &stdout,
+		stderr:   &stderr,
+		colors:   colors,
+		workflow: NewWorkflow(),
+		term:     mockTerm,
 	}
 
 	handler := &KeyHandler{ui: ui}
+	ui.handler = handler
 
-	result := handler.processCommand("commit <message>")
+	result, canceled := handler.processCommand("commit <message>")
+	if canceled {
+		t.Fatal("processCommand should not cancel for provided placeholder input")
+	}
 
 	expected := []string{"ggc", "commit", "fix", "bug"}
 	if len(result) != len(expected) {
@@ -1144,6 +1165,220 @@ func TestKeyHandler_ProcessCommand_WithPlaceholders(t *testing.T) {
 	}
 }
 
+func TestKeyHandler_HandleSoftCancelResetsState(t *testing.T) {
+	colors := NewANSIColors()
+	ui := &UI{
+		stdout: &bytes.Buffer{},
+		colors: colors,
+		state: &UIState{
+			input:        "status",
+			context:      ContextSearch,
+			contextStack: []Context{ContextInput},
+			showWorkflow: true,
+			selected:     2,
+		},
+	}
+
+	handler := &KeyHandler{ui: ui}
+	ui.handler = handler
+
+	handler.handleSoftCancel(nil)
+
+	if ui.state.HasInput() {
+		t.Error("expected input to be cleared after soft cancel")
+	}
+	if ui.state.showWorkflow {
+		t.Error("expected workflow view to be hidden after soft cancel")
+	}
+	if ui.state.GetCurrentContext() != ContextGlobal {
+		t.Errorf("expected context to reset to global, got %s", ui.state.GetCurrentContext())
+	}
+	if !ui.consumeSoftCancelFlash() {
+		t.Error("expected soft cancel flash flag to be set")
+	}
+
+	// Second soft cancel with no active state should not flash again
+	handler.handleSoftCancel(nil)
+	if ui.consumeSoftCancelFlash() {
+		t.Error("expected no flash when soft cancel called without active operation")
+	}
+}
+
+func TestShouldHandleEscapeAsSoftCancel(t *testing.T) {
+	ui := &UI{
+		stdin:  os.Stdin,
+		stdout: &bytes.Buffer{},
+		colors: NewANSIColors(),
+		state: &UIState{
+			context: ContextGlobal,
+		},
+	}
+
+	handler := &KeyHandler{ui: ui}
+	ui.handler = handler
+
+	restoreZero := termio.SetPendingInputFunc(func(uintptr) (int, error) { return 0, nil })
+	got := handler.shouldHandleEscapeAsSoftCancel()
+	restoreZero()
+	if !got {
+		t.Fatal("expected soft cancel to trigger when no input is pending")
+	}
+
+	ui.reader = bufio.NewReader(strings.NewReader("buffered"))
+	_, _ = ui.reader.Peek(1)
+	if handler.shouldHandleEscapeAsSoftCancel() {
+		t.Fatal("expected buffered reader to prevent soft cancel")
+	}
+	ui.reader = nil
+
+	restorePending := termio.SetPendingInputFunc(func(uintptr) (int, error) { return 1, nil })
+	if handler.shouldHandleEscapeAsSoftCancel() {
+		t.Fatal("expected pending input to prevent soft cancel")
+	}
+	restorePending()
+}
+
+// TestHandleKey_EscapeWithReaderParameter tests that ESC key (byte 27) correctly
+// handles both soft cancel and escape sequences with the reader parameter.
+// This test ensures the merge conflict resolution between soft cancel logic
+// and reader parameter addition remains stable.
+func TestHandleKey_EscapeWithReaderParameter(t *testing.T) {
+	t.Run("soft cancel when no pending input", func(t *testing.T) {
+		ui := &UI{
+			stdin:  os.Stdin,
+			stdout: &bytes.Buffer{},
+			colors: NewANSIColors(),
+			state: &UIState{
+				context:  ContextGlobal,
+				input:    "test",
+				filtered: []CommandInfo{},
+			},
+			workflow: NewWorkflow(),
+		}
+
+		handler := &KeyHandler{ui: ui}
+		ui.handler = handler
+
+		// Mock no pending input to trigger soft cancel
+		restoreZero := termio.SetPendingInputFunc(func(uintptr) (int, error) { return 0, nil })
+		defer restoreZero()
+
+		// ESC with no pending input should trigger soft cancel
+		shouldContinue, result := handler.HandleKey(27, true, nil, nil)
+		if !shouldContinue {
+			t.Error("Expected to continue after ESC soft cancel")
+		}
+		if result != nil {
+			t.Error("Expected nil result for ESC soft cancel")
+		}
+	})
+
+	t.Run("escape sequence when input pending", func(t *testing.T) {
+		ui := &UI{
+			stdin:  os.Stdin,
+			stdout: &bytes.Buffer{},
+			colors: NewANSIColors(),
+			state: &UIState{
+				context:   ContextGlobal,
+				input:     "test",
+				cursorPos: 4,
+				filtered:  []CommandInfo{},
+			},
+			workflow: NewWorkflow(),
+		}
+
+		handler := &KeyHandler{ui: ui}
+		ui.handler = handler
+
+		// Mock pending input to prevent soft cancel and trigger escape sequence
+		restorePending := termio.SetPendingInputFunc(func(uintptr) (int, error) { return 1, nil })
+		defer restorePending()
+
+		// Create a reader with escape sequence for left arrow: ESC [ D
+		reader := bufio.NewReader(strings.NewReader("[D"))
+
+		// ESC with pending input should handle escape sequence
+		shouldContinue, result := handler.HandleKey(27, true, nil, reader)
+		if !shouldContinue {
+			t.Error("Expected to continue after ESC sequence")
+		}
+		if result != nil {
+			t.Error("Expected nil result for ESC sequence")
+		}
+
+		// Cursor should have moved left from position 4 to 3
+		if ui.state.cursorPos != 3 {
+			t.Errorf("Expected cursor position 3 after left arrow, got %d", ui.state.cursorPos)
+		}
+	})
+
+	t.Run("escape sequence with buffered reader", func(t *testing.T) {
+		ui := &UI{
+			stdin:  os.Stdin,
+			stdout: &bytes.Buffer{},
+			colors: NewANSIColors(),
+			state: &UIState{
+				context:   ContextGlobal,
+				input:     "test",
+				cursorPos: 0,
+				filtered:  []CommandInfo{},
+			},
+			workflow: NewWorkflow(),
+		}
+
+		handler := &KeyHandler{ui: ui}
+		ui.handler = handler
+
+		// Create buffered reader with right arrow sequence: ESC [ C
+		reader := bufio.NewReader(strings.NewReader("[C"))
+		_, _ = reader.Peek(1) // Buffer some data
+
+		// With buffered reader, should handle escape sequence instead of soft cancel
+		shouldContinue, result := handler.HandleKey(27, true, nil, reader)
+		if !shouldContinue {
+			t.Error("Expected to continue after ESC sequence with buffered reader")
+		}
+		if result != nil {
+			t.Error("Expected nil result for ESC sequence")
+		}
+
+		// Cursor should have moved right from position 0 to 1
+		if ui.state.cursorPos != 1 {
+			t.Errorf("Expected cursor position 1 after right arrow, got %d", ui.state.cursorPos)
+		}
+	})
+}
+
+func TestRealTimeEditorShouldSoftCancelOnEscape(t *testing.T) {
+	colors := NewANSIColors()
+	ui := &UI{stdout: &bytes.Buffer{}, colors: colors}
+	inputRunes := make([]rune, 0)
+	cursor := 0
+	editor := &realTimeEditor{
+		ui:         ui,
+		inputRunes: &inputRunes,
+		cursor:     &cursor,
+	}
+
+	restoreZero := termio.SetPendingInputFunc(func(uintptr) (int, error) { return 0, nil })
+	if !editor.shouldSoftCancelOnEscape(bufio.NewReader(strings.NewReader(""))) {
+		t.Fatal("expected soft cancel when no bytes pending")
+	}
+	restoreZero()
+
+	restorePending := termio.SetPendingInputFunc(func(uintptr) (int, error) { return 1, nil })
+	if editor.shouldSoftCancelOnEscape(bufio.NewReader(strings.NewReader(""))) {
+		t.Fatal("expected pending input to block soft cancel")
+	}
+	restorePending()
+
+	bufferedReader := bufio.NewReader(strings.NewReader("buffer"))
+	_, _ = bufferedReader.Peek(1)
+	if editor.shouldSoftCancelOnEscape(bufferedReader) {
+		t.Fatal("expected buffered reader to block soft cancel")
+	}
+}
+
 func TestKeyHandler_GetLineInput(t *testing.T) {
 	var stdout, stderr bytes.Buffer
 	colors := NewANSIColors()
@@ -1158,7 +1393,10 @@ func TestKeyHandler_GetLineInput(t *testing.T) {
 
 	handler := &KeyHandler{ui: ui}
 
-	result := handler.getLineInput()
+	result, canceled := handler.getLineInput()
+	if canceled {
+		t.Fatal("expected line input to succeed")
+	}
 
 	if result != "test input" {
 		t.Errorf("Expected 'test input', got '%s'", result)
@@ -1180,7 +1418,10 @@ func TestKeyHandler_GetLineInput_EmptyInput(t *testing.T) {
 
 	handler := &KeyHandler{ui: ui}
 
-	result := handler.getLineInput()
+	result, canceled := handler.getLineInput()
+	if canceled {
+		t.Fatal("expected line input to succeed after retry")
+	}
 
 	if result != "valid input" {
 		t.Errorf("Expected 'valid input', got '%s'", result)
@@ -1206,11 +1447,9 @@ func TestRenderer_KeybindDisplay(t *testing.T) {
 
 	state := &UIState{
 		selected:  0,
-		input:     "test",
-		cursorPos: 4,
-		filtered: []CommandInfo{
-			{"test command", "test description"},
-		},
+		input:     "", // Empty input to show keybind help
+		cursorPos: 0,
+		filtered:  []CommandInfo{}, // Empty to show keybind help
 	}
 
 	ui := &UI{
@@ -1221,34 +1460,28 @@ func TestRenderer_KeybindDisplay(t *testing.T) {
 		renderer: renderer,
 		state:    state,
 		colors:   colors,
+		workflow: NewWorkflow(),
 	}
 
 	renderer.Render(ui, state)
 	output := buf.String()
 
-	// Check that lowercase keybind notation is used
+	// Check that keybind help is displayed
 	expectedKeybinds := []string{
-		"Ctrl+n/p",
-		"Ctrl+a/e",
+		"Available keybinds:",
+		"Ctrl+u",
+		"Ctrl+w",
+		"Ctrl+k",
+		"Ctrl+a",
+		"Ctrl+e",
 		"Ctrl+c",
+		"Tab",
+		"Ctrl+t",
 	}
 
 	for _, keybind := range expectedKeybinds {
 		if !strings.Contains(output, keybind) {
-			t.Errorf("Expected output to contain lowercase keybind '%s', but it was not found", keybind)
-		}
-	}
-
-	// Check that uppercase versions are NOT used
-	uppercaseKeybinds := []string{
-		"Ctrl+N/P",
-		"Ctrl+A/E",
-		"Ctrl+C",
-	}
-
-	for _, keybind := range uppercaseKeybinds {
-		if strings.Contains(output, keybind) {
-			t.Errorf("Expected output to NOT contain uppercase keybind '%s', but it was found", keybind)
+			t.Errorf("Expected output to contain keybind '%s', but it was not found", keybind)
 		}
 	}
 }
@@ -1276,12 +1509,13 @@ func TestKeyHandler_HandleKey(t *testing.T) {
 		renderer: renderer,
 		state:    state,
 		colors:   colors,
+		workflow: NewWorkflow(),
 	}
 
 	handler := &KeyHandler{ui: ui}
 
 	// Test printable character
-	shouldContinue, result := handler.HandleKey('a', true, nil)
+	shouldContinue, result := handler.HandleKey('a', true, nil, nil)
 	if !shouldContinue {
 		t.Error("Expected to continue after printable character")
 	}
@@ -1293,7 +1527,7 @@ func TestKeyHandler_HandleKey(t *testing.T) {
 	}
 
 	// Test backspace
-	shouldContinue, _ = handler.HandleKey(127, true, nil)
+	shouldContinue, _ = handler.HandleKey(127, true, nil, nil)
 	if !shouldContinue {
 		t.Error("Expected to continue after backspace")
 	}
@@ -1524,3 +1758,312 @@ func TestHandleInputChar_MultibyteDisplay(t *testing.T) {
 		})
 	}
 }
+
+// TestKeyHandler_HandleWorkflowKeys tests workflow key handling
+func TestKeyHandler_HandleWorkflowKeys(t *testing.T) {
+	tests := []struct {
+		name           string
+		key            rune
+		showWorkflow   bool
+		hasInput       bool
+		selectedCmd    *CommandInfo
+		expectedResult bool
+		expectedAction string
+	}{
+		{
+			name:           "Tab key adds command to workflow",
+			key:            '\t',
+			showWorkflow:   false,
+			hasInput:       true,
+			selectedCmd:    &CommandInfo{Command: "add .", Description: "Add all changes"},
+			expectedResult: true,
+			expectedAction: "add_to_workflow",
+		},
+		{
+			name:           "Tab key in workflow view returns true but no action",
+			key:            '\t',
+			showWorkflow:   true,
+			hasInput:       true,
+			selectedCmd:    &CommandInfo{Command: "add .", Description: "Add all changes"},
+			expectedResult: true,
+			expectedAction: "no_action",
+		},
+		{
+			name:           "c key clears workflow in workflow view",
+			key:            'c',
+			showWorkflow:   true,
+			hasInput:       false,
+			selectedCmd:    nil,
+			expectedResult: true,
+			expectedAction: "clear_workflow",
+		},
+		{
+			name:           "c key in search view returns false because it is unhandled",
+			key:            'c',
+			showWorkflow:   false,
+			hasInput:       true,
+			selectedCmd:    nil,
+			expectedResult: false,
+			expectedAction: "no_action",
+		},
+		{
+			name:           "unhandled key returns false",
+			key:            'x',
+			showWorkflow:   false,
+			hasInput:       true,
+			selectedCmd:    nil,
+			expectedResult: false,
+			expectedAction: "none",
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			// Setup
+			gitClient := &mockGitClient{}
+			ui := NewUI(gitClient)
+			ui.state.showWorkflow = tt.showWorkflow
+			if tt.hasInput {
+				ui.state.input = "test"
+				ui.state.filtered = []CommandInfo{
+					{Command: "add .", Description: "Add all changes"},
+				}
+				ui.state.selected = 0
+			}
+
+			// Mock workflow for clear test
+			if tt.expectedAction == "clear_workflow" {
+				ui.workflow.AddStep("test", []string{}, "test command")
+			}
+
+			// Execute
+			result := ui.handler.handleWorkflowKeys(tt.key)
+
+			// Verify
+			if result != tt.expectedResult {
+				t.Errorf("Expected result %v, got %v", tt.expectedResult, result)
+			}
+
+			// Verify side effects
+			switch tt.expectedAction {
+			case "add_to_workflow":
+				if ui.workflow.IsEmpty() {
+					t.Error("Expected workflow to have steps after adding command")
+				}
+			case "clear_workflow":
+				if !ui.workflow.IsEmpty() {
+					t.Error("Expected workflow to be empty after clearing")
+				}
+			}
+		})
+	}
+}
+
+// TestKeyHandler_AddCommandToWorkflow tests adding commands to workflow
+func TestKeyHandler_AddCommandToWorkflow(t *testing.T) {
+	tests := []struct {
+		name        string
+		cmdTemplate string
+		expectSteps int
+	}{
+		{
+			name:        "Add simple command",
+			cmdTemplate: "add .",
+			expectSteps: 1,
+		},
+		{
+			name:        "Add command with placeholder",
+			cmdTemplate: "commit <message>",
+			expectSteps: 1,
+		},
+		{
+			name:        "Add complex command",
+			cmdTemplate: "branch create <name>",
+			expectSteps: 1,
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			// Setup
+			gitClient := &mockGitClient{}
+			ui := NewUI(gitClient)
+
+			// Redirect output to avoid test output pollution
+			ui.stdout = &bytes.Buffer{}
+
+			// Execute
+			ui.handler.addCommandToWorkflow(tt.cmdTemplate)
+
+			// Verify
+			steps := ui.workflow.GetSteps()
+			if len(steps) != tt.expectSteps {
+				t.Errorf("Expected %d steps, got %d", tt.expectSteps, len(steps))
+			}
+
+			if len(steps) > 0 {
+				if steps[0].Description != tt.cmdTemplate {
+					t.Errorf("Expected description '%s', got '%s'", tt.cmdTemplate, steps[0].Description)
+				}
+			}
+		})
+	}
+}
+
+// TestKeyHandler_ClearWorkflow tests clearing workflow
+func TestKeyHandler_ClearWorkflow(t *testing.T) {
+	// Setup
+	gitClient := &mockGitClient{}
+	ui := NewUI(gitClient)
+
+	// Redirect output to avoid test output pollution
+	ui.stdout = &bytes.Buffer{}
+
+	// Add some steps
+	ui.workflow.AddStep("add", []string{"."}, "add .")
+	ui.workflow.AddStep("commit", []string{"-m", "test"}, "commit -m test")
+
+	if ui.workflow.IsEmpty() {
+		t.Fatal("Expected workflow to have steps before clearing")
+	}
+
+	// Execute
+	ui.handler.clearWorkflow()
+
+	// Verify
+	if !ui.workflow.IsEmpty() {
+		t.Error("Expected workflow to be empty after clearing")
+	}
+}
+
+// TestUI_ToggleWorkflowView tests workflow view toggling
+func TestUI_ToggleWorkflowView(t *testing.T) {
+	// Setup
+	gitClient := &mockGitClient{}
+	ui := NewUI(gitClient)
+
+	// Initial state should be false
+	if ui.state.showWorkflow {
+		t.Error("Expected initial showWorkflow to be false")
+	}
+
+	// Toggle to true
+	ui.ToggleWorkflowView()
+	if !ui.state.showWorkflow {
+		t.Error("Expected showWorkflow to be true after first toggle")
+	}
+
+	// Toggle back to false
+	ui.ToggleWorkflowView()
+	if ui.state.showWorkflow {
+		t.Error("Expected showWorkflow to be false after second toggle")
+	}
+}
+
+// TestUI_WorkflowOperations tests workflow operations
+func TestUI_WorkflowOperations(t *testing.T) {
+	// Setup
+	gitClient := &mockGitClient{}
+	ui := NewUI(gitClient)
+
+	// Test AddToWorkflow
+	id := ui.AddToWorkflow("add", []string{"."}, "add .")
+	if id != 1 {
+		t.Errorf("Expected first workflow ID to be 1, got %d", id)
+	}
+
+	steps := ui.workflow.GetSteps()
+	if len(steps) != 1 {
+		t.Errorf("Expected 1 step, got %d", len(steps))
+	}
+
+	// Test ClearWorkflow
+	ui.ClearWorkflow()
+	if !ui.workflow.IsEmpty() {
+		t.Error("Expected workflow to be empty after clearing")
+	}
+}
+
+// TestKeyHandler_ExecuteWorkflow tests workflow execution
+func TestKeyHandler_ExecuteWorkflow(t *testing.T) {
+	tests := []struct {
+		name           string
+		workflowSteps  []struct{ cmd, desc string }
+		expectError    bool
+		expectResult   bool
+		expectContinue bool
+	}{
+		{
+			name:           "Execute empty workflow",
+			workflowSteps:  []struct{ cmd, desc string }{},
+			expectError:    false,
+			expectResult:   false, // Empty workflow returns (true, nil)
+			expectContinue: true,
+		},
+		{
+			name: "Execute workflow with steps",
+			workflowSteps: []struct{ cmd, desc string }{
+				{"add .", "add ."},
+				{"commit -m test", "commit -m test"},
+			},
+			expectError:    false,
+			expectResult:   true, // Non-empty workflow returns result
+			expectContinue: false,
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			// Setup
+			gitClient := &mockGitClient{}
+			ui := NewUI(gitClient)
+
+			// Redirect output to avoid test output pollution
+			ui.stdout = &bytes.Buffer{}
+
+			// Set up workflow executor with mock router
+			mockRouter := &mockRouterForExecute{}
+			ui.workflowEx = NewWorkflowExecutor(mockRouter, ui)
+
+			// Add workflow steps
+			for _, step := range tt.workflowSteps {
+				parts := strings.Fields(step.cmd)
+				if len(parts) > 0 {
+					ui.workflow.AddStep(parts[0], parts[1:], step.desc)
+				}
+			}
+
+			// Execute
+			shouldContinue, result := ui.handler.executeWorkflow(nil)
+
+			// Verify
+			if shouldContinue != tt.expectContinue {
+				t.Errorf("Expected shouldContinue %v, got %v", tt.expectContinue, shouldContinue)
+			}
+
+			if tt.expectResult {
+				if result == nil {
+					t.Error("Expected result to not be nil")
+				} else if len(result) < 2 || result[1] != InteractiveWorkflowCommand {
+					t.Errorf("Expected result to contain workflow command, got %v", result)
+				}
+			} else {
+				if result != nil {
+					t.Errorf("Expected result to be nil for empty workflow, got %v", result)
+				}
+			}
+		})
+	}
+}
+
+// mockRouterForExecute is a mock router for testing workflow execution
+type mockRouterForExecute struct {
+	routedCommands [][]string
+}
+
+func (m *mockRouterForExecute) Route(args []string) {
+	if m.routedCommands == nil {
+		m.routedCommands = make([][]string, 0)
+	}
+	m.routedCommands = append(m.routedCommands, args)
+}
