@@ -13,7 +13,8 @@ import (
 
 	"go.yaml.in/yaml/v3"
 
-	"github.com/bmf-san/ggc/v5/git"
+	"github.com/bmf-san/ggc/v7/git"
+	"github.com/bmf-san/ggc/v7/internal/security"
 )
 
 // TempFile interface for temporary file operations
@@ -95,13 +96,19 @@ type Config struct {
 		Profile string `yaml:"profile,omitempty"`
 
 		Keybindings struct {
-			DeleteWord      string `yaml:"delete_word"`
-			ClearLine       string `yaml:"clear_line"`
-			DeleteToEnd     string `yaml:"delete_to_end"`
-			MoveToBeginning string `yaml:"move_to_beginning"`
-			MoveToEnd       string `yaml:"move_to_end"`
-			MoveUp          string `yaml:"move_up"`
-			MoveDown        string `yaml:"move_down"`
+			DeleteWord         string `yaml:"delete_word"`
+			ClearLine          string `yaml:"clear_line"`
+			DeleteToEnd        string `yaml:"delete_to_end"`
+			MoveToBeginning    string `yaml:"move_to_beginning"`
+			MoveToEnd          string `yaml:"move_to_end"`
+			MoveUp             string `yaml:"move_up"`
+			MoveDown           string `yaml:"move_down"`
+			MoveLeft           string `yaml:"move_left"`
+			MoveRight          string `yaml:"move_right"`
+			AddToWorkflow      string `yaml:"add_to_workflow"`
+			ToggleWorkflowView string `yaml:"toggle_workflow_view"`
+			ClearWorkflow      string `yaml:"clear_workflow"`
+			SoftCancel         string `yaml:"soft_cancel"`
 		} `yaml:"keybindings"`
 
 		Contexts struct {
@@ -350,6 +357,7 @@ func validateAliasSequence(name string, seq []interface{}) error {
 	if len(seq) == 0 {
 		return &ValidationError{"aliases." + name, seq, "alias sequence cannot be empty"}
 	}
+
 	for i, cmd := range seq {
 		cmdStr, ok := cmd.(string)
 		if !ok {
@@ -358,6 +366,15 @@ func validateAliasSequence(name string, seq []interface{}) error {
 		if strings.TrimSpace(cmdStr) == "" {
 			return &ValidationError{Field: fmt.Sprintf("aliases.%s[%d]", name, i), Value: cmdStr, Message: "command in sequence cannot be empty"}
 		}
+
+		// Validate command security
+		if err := security.ValidateCommand(cmdStr); err != nil {
+			return &ValidationError{
+				Field:   fmt.Sprintf("aliases.%s[%d]", name, i),
+				Value:   cmdStr,
+				Message: err.Error(),
+			}
+		}
 	}
 	return nil
 }
@@ -722,15 +739,16 @@ func (cm *Manager) replaceConfigFile(tmpName string) error {
 }
 
 func (cm *Manager) replaceConfigFileWithOps(tmpName string, fileOps FileOps) error {
+	// On Windows versions prior to 10 1903, os.Rename requires the target not exist, so remove it first.
+	// Modern Windows (10 1903+) and Unix support atomic replacement with os.Rename, but we remove the target for compatibility.
 	if runtime.GOOS == "windows" {
 		_ = fileOps.Remove(cm.configPath)
 	}
+
+	// Perform atomic rename - this is the only file system operation that matters
 	if err := fileOps.Rename(tmpName, cm.configPath); err != nil {
-		_ = fileOps.Remove(cm.configPath)
-		if err2 := fileOps.Rename(tmpName, cm.configPath); err2 != nil {
-			_ = fileOps.Remove(tmpName)
-			return fmt.Errorf("failed to replace config file: %w", err2)
-		}
+		_ = fileOps.Remove(tmpName)
+		return fmt.Errorf("failed to replace config file: %w", err)
 	}
 	return nil
 }
@@ -989,13 +1007,19 @@ func (c *Config) validateKeybindings() error {
 
 	// Validate global keybindings
 	bindings := map[string]string{
-		"delete_word":       c.Interactive.Keybindings.DeleteWord,
-		"clear_line":        c.Interactive.Keybindings.ClearLine,
-		"delete_to_end":     c.Interactive.Keybindings.DeleteToEnd,
-		"move_to_beginning": c.Interactive.Keybindings.MoveToBeginning,
-		"move_to_end":       c.Interactive.Keybindings.MoveToEnd,
-		"move_up":           c.Interactive.Keybindings.MoveUp,
-		"move_down":         c.Interactive.Keybindings.MoveDown,
+		"delete_word":          c.Interactive.Keybindings.DeleteWord,
+		"clear_line":           c.Interactive.Keybindings.ClearLine,
+		"delete_to_end":        c.Interactive.Keybindings.DeleteToEnd,
+		"move_to_beginning":    c.Interactive.Keybindings.MoveToBeginning,
+		"move_to_end":          c.Interactive.Keybindings.MoveToEnd,
+		"move_up":              c.Interactive.Keybindings.MoveUp,
+		"move_down":            c.Interactive.Keybindings.MoveDown,
+		"move_left":            c.Interactive.Keybindings.MoveLeft,
+		"move_right":           c.Interactive.Keybindings.MoveRight,
+		"add_to_workflow":      c.Interactive.Keybindings.AddToWorkflow,
+		"toggle_workflow_view": c.Interactive.Keybindings.ToggleWorkflowView,
+		"clear_workflow":       c.Interactive.Keybindings.ClearWorkflow,
+		"soft_cancel":          c.Interactive.Keybindings.SoftCancel,
 	}
 
 	for action, keyStr := range bindings {
