@@ -11,7 +11,7 @@ import (
 
 	"go.yaml.in/yaml/v3"
 
-	"github.com/bmf-san/ggc/v5/internal/testutil"
+	"github.com/bmf-san/ggc/v7/internal/testutil"
 )
 
 // MockFileOps implements FileOps for testing
@@ -167,19 +167,38 @@ func TestNewConfigManager(t *testing.T) {
 	mockClient := testutil.NewMockGitClient()
 	cm := NewConfigManager(mockClient)
 
-	if cm == nil {
-		t.Fatal("Expected config manager to be created")
-	}
-	if cm.config == nil {
-		t.Fatal("Expected config to be initialized")
-	}
-	if cm.configPath != "" {
-		t.Errorf("Expected configPath to be empty initially, got %s", cm.configPath)
-	}
+	t.Run("manager_creation", func(t *testing.T) {
+		if cm == nil {
+			t.Fatal("Expected config manager to be created")
+		}
+	})
 
-	if cm.config.Default.Branch != "main" {
-		t.Errorf("Expected default branch to be 'main', got %s", cm.config.Default.Branch)
-	}
+	t.Run("config_initialization", func(t *testing.T) {
+		if cm == nil {
+			t.Skip("Skipping due to nil manager")
+		}
+		if cm.config == nil {
+			t.Fatal("Expected config to be initialized")
+		}
+	})
+
+	t.Run("config_path_initialization", func(t *testing.T) {
+		if cm == nil {
+			t.Skip("Skipping due to nil manager")
+		}
+		if cm.configPath != "" {
+			t.Fatalf("Expected configPath to be empty initially, got: %s", cm.configPath)
+		}
+	})
+
+	t.Run("default_branch", func(t *testing.T) {
+		if cm == nil || cm.config == nil {
+			t.Skip("Skipping due to nil manager or config")
+		}
+		if cm.config.Default.Branch != "main" {
+			t.Errorf("Expected default branch to be 'main', got %s", cm.config.Default.Branch)
+		}
+	})
 }
 
 // TestGetConfigPaths tests the configuration path resolution
@@ -391,7 +410,7 @@ func TestGetValueByPath(t *testing.T) {
 			continue
 		}
 
-		if !reflect.DeepEqual(value, tc.expected) {
+		if value != tc.expected {
 			t.Errorf("Expected value for path %s to be %v, got %v", tc.path, tc.expected, value)
 		}
 	}
@@ -445,7 +464,7 @@ func TestSetValueByPath(t *testing.T) {
 			continue
 		}
 
-		if !reflect.DeepEqual(actualValue, tc.expected) {
+		if actualValue != tc.expected {
 			t.Errorf("Expected value for path %s to be %v, got %v", tc.path, tc.expected, actualValue)
 		}
 	}
@@ -1067,6 +1086,77 @@ func TestConfig_validateAliases(t *testing.T) {
 			wantError: true,
 			errorMsg:  "sequence commands must be strings",
 		},
+		{
+			name: "sequence alias with semicolon injection blocked at config load",
+			aliases: map[string]interface{}{
+				"malicious": []interface{}{"status; echo pwned"},
+			},
+			wantError: true,
+			errorMsg:  "unsafe shell metacharacters",
+		},
+		{
+			name: "sequence alias with pipe injection blocked at config load",
+			aliases: map[string]interface{}{
+				"malicious": []interface{}{"status | cat"},
+			},
+			wantError: true,
+			errorMsg:  "unsafe shell metacharacters",
+		},
+		{
+			name: "sequence alias with ampersand injection blocked at config load",
+			aliases: map[string]interface{}{
+				"malicious": []interface{}{"status && echo pwned"},
+			},
+			wantError: true,
+			errorMsg:  "unsafe shell metacharacters",
+		},
+		{
+			name: "sequence alias with command substitution blocked at config load",
+			aliases: map[string]interface{}{
+				"malicious": []interface{}{"status $(whoami)"},
+			},
+			wantError: true,
+			errorMsg:  "unsafe shell metacharacters",
+		},
+		{
+			name: "sequence alias with backtick injection blocked at config load",
+			aliases: map[string]interface{}{
+				"malicious": []interface{}{"`whoami`"},
+			},
+			wantError: true,
+			errorMsg:  "unsafe shell metacharacters",
+		},
+		{
+			name: "sequence alias with redirection blocked at config load",
+			aliases: map[string]interface{}{
+				"malicious": []interface{}{"status > /tmp/out"},
+			},
+			wantError: true,
+			errorMsg:  "unsafe shell metacharacters",
+		},
+		{
+			name: "sequence alias with invalid command blocked at config load",
+			aliases: map[string]interface{}{
+				"bad": []interface{}{"notacommand"},
+			},
+			wantError: true,
+			errorMsg:  "not a valid ggc command",
+		},
+		{
+			name: "sequence alias with mixed valid and invalid blocked at config load",
+			aliases: map[string]interface{}{
+				"bad": []interface{}{"status", "invalidcmd", "branch"},
+			},
+			wantError: true,
+			errorMsg:  "not a valid ggc command",
+		},
+		{
+			name: "sequence alias with valid commands and args passes validation",
+			aliases: map[string]interface{}{
+				"good": []interface{}{"branch current", "status short", "diff staged"},
+			},
+			wantError: false,
+		},
 	}
 
 	for _, tt := range tests {
