@@ -2,7 +2,7 @@ package git
 
 import (
 	"os/exec"
-	"reflect"
+	"slices"
 	"testing"
 )
 
@@ -34,7 +34,7 @@ func TestClient_Pull(t *testing.T) {
 				},
 			}
 			_ = client.Pull(tc.rebase)
-			if !reflect.DeepEqual(gotArgs, tc.wantArgs) {
+			if !slices.Equal(gotArgs, tc.wantArgs) {
 				t.Errorf("got %v, want %v", gotArgs, tc.wantArgs)
 			}
 		})
