@@ -5,7 +5,7 @@
 package testutil
 
 import (
-	"github.com/bmf-san/ggc/v5/git"
+	"github.com/bmf-san/ggc/v7/git"
 )
 
 // NewMockGitClient creates a new mock git client for testing
@@ -49,6 +49,9 @@ func (m *testMockGitClient) CommitAllowEmpty() error               { return nil
 func (m *testMockGitClient) Diff() (string, error)       { return "", nil }
 func (m *testMockGitClient) DiffStaged() (string, error) { return "", nil }
 func (m *testMockGitClient) DiffHead() (string, error)   { return "", nil }
+func (m *testMockGitClient) DiffWith(_ []string) (string, error) {
+	return "", nil
+}
 
 // Branch Operations
 func (m *testMockGitClient) ListLocalBranches() ([]string, error) { return []string{"main"}, nil }
