@@ -6,8 +6,8 @@ import (
 	"os"
 	"strings"
 
-	"github.com/bmf-san/ggc/v5/cmd"
-	"github.com/bmf-san/ggc/v5/config"
+	"github.com/bmf-san/ggc/v7/cmd"
+	"github.com/bmf-san/ggc/v7/config"
 )
 
 // Router represents the command router with config support.
@@ -18,7 +18,10 @@ type Router struct {
 
 // NewRouter creates a new Router with a config manager.
 func NewRouter(e cmd.Executer, cm *config.Manager) *Router {
-	return &Router{Executer: e, ConfigManager: cm}
+	return &Router{
+		Executer:      e,
+		ConfigManager: cm,
+	}
 }
 
 // Route routes the command to the appropriate handler
@@ -74,26 +77,27 @@ type commandHandler func([]string)
 // getCommandHandlers returns a map of command names to their handlers
 func (r *Router) getCommandHandlers() map[string]commandHandler {
 	return map[string]commandHandler{
-		"help":    func(_ []string) { r.Executer.Help() },
-		"add":     r.Executer.Add,
-		"branch":  r.Executer.Branch,
-		"clean":   r.Executer.Clean,
-		"commit":  r.Executer.Commit,
-		"config":  r.Executer.Config,
-		"diff":    r.Executer.Diff,
-		"fetch":   r.Executer.Fetch,
-		"hook":    r.Executer.Hook,
-		"log":     r.Executer.Log,
-		"pull":    r.Executer.Pull,
-		"push":    r.Executer.Push,
-		"rebase":  r.Executer.Rebase,
-		"remote":  r.Executer.Remote,
-		"reset":   r.Executer.Reset,
-		"restore": r.Executer.Restore,
-		"stash":   r.Executer.Stash,
-		"status":  r.Executer.Status,
-		"tag":     r.Executer.Tag,
-		"version": r.Executer.Version,
+		"help":       func(_ []string) { r.Executer.Help() },
+		"add":        r.Executer.Add,
+		"branch":     r.Executer.Branch,
+		"clean":      r.Executer.Clean,
+		"commit":     r.Executer.Commit,
+		"config":     r.Executer.Config,
+		"debug-keys": r.Executer.DebugKeys,
+		"diff":       r.Executer.Diff,
+		"fetch":      r.Executer.Fetch,
+		"hook":       r.Executer.Hook,
+		"log":        r.Executer.Log,
+		"pull":       r.Executer.Pull,
+		"push":       r.Executer.Push,
+		"rebase":     r.Executer.Rebase,
+		"remote":     r.Executer.Remote,
+		"reset":      r.Executer.Reset,
+		"restore":    r.Executer.Restore,
+		"stash":      r.Executer.Stash,
+		"status":     r.Executer.Status,
+		"tag":        r.Executer.Tag,
+		"version":    r.Executer.Version,
 	}
 }
 
